Structs
- Dummy
- An empty Dummy type. Each trait generated by the
doublemacro will be implemented for this type.
Attribute Macros
- double
- Generates a trait which replicates the original trait method for method. It does implement the
original trait for each of its implementations, by means of forwarding the method calls. The
utility comes from the fact that the generated trait has default implementations for each method
using
unimplemented!(), which makes it useful for testing purposes.